@@ -18,12 +18,13 @@ package org.apache.qpid.jms.transports.netty;
 
 import static org.hamcrest.MatcherAssert.assertThat;
 import static org.hamcrest.collection.IsIterableContainingInAnyOrder.containsInAnyOrder;
-import static org.junit.Assert.assertArrayEquals;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertArrayEquals;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertThrows;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.net.URI;
 import java.net.URLEncoder;
@@ -32,7 +33,7 @@ import java.util.List;
 
 import org.apache.qpid.jms.transports.Transport;
 import org.apache.qpid.jms.transports.TransportOptions;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 /**
  * Test the NettySslTransportFactoryTest class
@@ -49,6 +50,7 @@ public class NettySslTransportFactoryTest {
     public static final int CUSTOM_CONNECT_TIMEOUT = 90000;
     private static final String CUSTOM_LOCAL_ADDRESS = "localhost";
     private static final int CUSTOM_LOCAL_PORT = 30000;
+    private static final int CUSTOM_SHARED_EVENT_LOOP_THREADS = 7;
 
     public static final String CUSTOM_CONTEXT_PROTOCOL = "TLSv1.2";
     public static final String[] CUSTOM_ENABLED_PROTOCOLS = { "TLSv1.1", "TLSv1.2" };
@@ -93,6 +95,7 @@ public class NettySslTransportFactoryTest {
         assertEquals(TransportOptions.DEFAULT_SO_TIMEOUT, options.getSoTimeout());
         assertNull(options.getLocalAddress());
         assertEquals(TransportOptions.DEFAULT_LOCAL_PORT, options.getLocalPort());
+        assertEquals(TransportOptions.DEFAULT_SHARED_EVENT_LOOP_THREADS, options.getSharedEventLoopThreads());
 
         assertEquals(TransportOptions.DEFAULT_CONTEXT_PROTOCOL, options.getContextProtocol());
         assertNull(options.getEnabledProtocols());
@@ -105,18 +108,22 @@ public class NettySslTransportFactoryTest {
         assertNull(options.getKeyAlias());
     }
 
-    @Test(expected = IllegalArgumentException.class)
+    @Test
     public void testCreateWithUnknownOption() throws Exception {
-        URI BASE_URI = new URI("ssl://localhost:5672?transport.someOption=true");
-        NettySslTransportFactory factory = new NettySslTransportFactory();
-        factory.createTransport(BASE_URI);
+        assertThrows(IllegalArgumentException.class, () -> {
+            URI BASE_URI = new URI("ssl://localhost:5672?transport.someOption=true");
+            NettySslTransportFactory factory = new NettySslTransportFactory();
+            factory.createTransport(BASE_URI);
+        });
     }
 
-    @Test(expected = IllegalArgumentException.class)
+    @Test
     public void testCreateWithBadOption() throws Exception {
-        URI BASE_URI = new URI("ssl://localhost:5672?transport.trafficClass=4096");
-        NettySslTransportFactory factory = new NettySslTransportFactory();
-        factory.createTransport(BASE_URI);
+        assertThrows(IllegalArgumentException.class, () -> {
+            URI BASE_URI = new URI("ssl://localhost:5672?transport.trafficClass=4096");
+            NettySslTransportFactory factory = new NettySslTransportFactory();
+            factory.createTransport(BASE_URI);
+        });
     }
 
     @Test
@@ -124,6 +131,7 @@ public class NettySslTransportFactoryTest {
         URI BASE_URI = new URI("tcp://localhost:5672");
 
         URI configuredURI = new URI(BASE_URI.toString() + "?" +
+            "transport.sharedEventLoopThreads=" + CUSTOM_SHARED_EVENT_LOOP_THREADS + "&" +
             "transport.connectTimeout=" + CUSTOM_CONNECT_TIMEOUT + "&" +
             "transport.sendBufferSize=" + CUSTOM_SEND_BUFFER_SIZE + "&" +
             "transport.receiveBufferSize=" + CUSTOM_RECEIVE_BUFFER_SIZE + "&" +
@@ -156,6 +164,7 @@ public class NettySslTransportFactoryTest {
         TransportOptions options = transport.getTransportOptions();
         assertNotNull(options);
 
+        assertEquals(CUSTOM_SHARED_EVENT_LOOP_THREADS, options.getSharedEventLoopThreads());
         assertEquals(CUSTOM_CONNECT_TIMEOUT, options.getConnectTimeout());
         assertEquals(CUSTOM_SEND_BUFFER_SIZE, options.getSendBufferSize());
         assertEquals(CUSTOM_RECEIVE_BUFFER_SIZE, options.getReceiveBufferSize());
